@@ -6,7 +6,8 @@ from evobench.separable import Separable
 class Trap(Separable, Discrete):
 
     def evaluate_block(self, block: np.ndarray, block_index: int) -> int:
-        if not block.any():
+        non_zero_count = np.count_nonzero(block)
+        if not non_zero_count:
             return block.size
         else:
-            return np.count_nonzero(block) - 1
+            return non_zero_count - 1
